SmartResponse class
Response object from the native side
Constructors
- SmartResponse({required bool success, String? data, String? dataEncoding, int? statusCode, String? error, String? errorType})
-
SmartResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data → String?
-
final
- dataBytes → Uint8List?
-
The response body as raw bytes.
no setter
- dataEncoding → String?
-
Encoding of data.
nullmeans plain UTF-8 text;'base64'means data is base64 and represents a binary (non-UTF-8) response body.final - error → String?
-
final
- errorType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBinary → bool
-
Whether data carries a binary (base64-encoded) body.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
final
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited